Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(634)

Unified Diff: third_party/WebKit/public/platform/WebInputEvent.h

Issue 2233543002: Make first TouchStart and first TouchMove events on a flinging layer non-blocking (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rename Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/web/WebInputEventConversion.cpp ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/platform/WebInputEvent.h
diff --git a/third_party/WebKit/public/platform/WebInputEvent.h b/third_party/WebKit/public/platform/WebInputEvent.h
index c7ccbf8fb7817a7aed86b220ef3841ddd5f655cd..e22529c73b20e42cb62f2e95c23d4a4f355a7ca2 100644
--- a/third_party/WebKit/public/platform/WebInputEvent.h
+++ b/third_party/WebKit/public/platform/WebInputEvent.h
@@ -202,8 +202,8 @@ public:
// All listeners are passive; not cancelable.
ListenersNonBlockingPassive,
// This value represents a state which would have normally blocking
- // but was forced to be non-blocking; not cancelable.
- ListenersForcedNonBlockingPassive,
+ // but was forced to be non-blocking during fling; not cancelable.
+ ListenersForcedNonBlockingDueToFling,
};
// The rail mode for a wheel event specifies the axis on which scrolling is
@@ -624,6 +624,9 @@ public:
// dispatched.
bool dispatchedDuringFling;
+ // Whether this touch event is a touchstart or a first touchmove event per scroll.
+ bool touchStartOrFirstTouchMove;
+
// A unique identifier for the touch event. Valid ids start at one and
// increase monotonically. Zero means an unknown id.
uint32_t uniqueTouchEventId;
@@ -634,6 +637,7 @@ public:
, dispatchType(Blocking)
, movedBeyondSlopRegion(false)
, dispatchedDuringFling(false)
+ , touchStartOrFirstTouchMove(false)
, uniqueTouchEventId(0)
{
}
« no previous file with comments | « third_party/WebKit/Source/web/WebInputEventConversion.cpp ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698